<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcConcentricThrough</name>
    <message>
        <location filename="../ArcConcentricThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <location filename="../ArcConcentricThroughInit.js" line="+2"/>
        <source>Concentric (&amp;through Point)</source>
        <translation>同心弧（以弧外点）(&amp;t)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw concentric arc through point</source>
        <translation>以弧外一点画同心弧</translation>
    </message>
</context>
</TS>
